/* qddb/Headers/Hash.h
 *
 * Copyright (C) 1993, 1994 Herrin Software Development, Inc.
 * All rights reserved.
 *
 * This file is part of Qddb.
 *
 * Qddb is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2
 * as published by the Free Software Foundation.
 *
 * Qddb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Qddb; see the file LICENSE.  If not, write to:
 *
 *	Herrin Software Development, Inc. 
 *	R&D Division
 *	41 South Highland Ave. 
 *	Prestonsburg, KY 41653 
 */

#if !defined(_QDDB_HASH_H_)
#define _QDDB_HASH_H_

#define DEFAULT_HASHSIZE	20000
#define DEFAULT_CACHESIZE	100
#define HASHLINESIZE		44
#define BASE10_HASHLINESIZE     HASHLINESIZE
#define BASE62_HASHLINESIZE     28

#define QDDB_HASHTYPE_DEFAULT	0
#define QDDB_HASHTYPE_MOD1	1
#define QDDB_HASHTYPE_MOD2	2
#define QDDB_HASHTYPE_MOD3	3
#define QDDB_HASHTYPE_MOD4	4
#define QDDB_HASHTYPE_MOD5	5

typedef struct {
		size_t		index, num;
		off_t		pos;
		size_t		len;
} Hash;

#endif
